@@ -7,19 +7,29 @@
 #include "comp_rle.h"
 #include "comp_delta.h"
 #ifdef USE_ZLIB
-#ifdef DEBUG
-#include "comp_luck.h"
-#endif
 #include "comp_zlib.h"
+#include "comp_mzlib.h"
 #endif
+#ifdef DEBUG
+#include "comp_factor.h"
+#endif
+#include "comp_text.h"
+#include "comp_fail.h"
 
 int (*(algorithms[256]))()={    comp_plain_algo,
                                 comp_rle_algo,
                                 comp_delta_algo,
+				comp_text_algo,
 #ifdef USE_ZLIB
-#ifdef DEBUG
-				comp_luck_algo,
-#endif
                                 comp_zlib_algo,
+				comp_mzlib_algo,
+#else
+				comp_fail_algo,
+				comp_fail_algo,
+#endif
+#ifdef DEBUG
+				comp_factor_algo,
+#else
+				comp_fail_algo,
 #endif
                                 NULL};
