@@ -1,5 +1,5 @@
 /*
-	Example block compression routine for interfacing with DCL.
+	Example block compression routine for interfacing with DACT.
 
 	This does no compression.
 
@@ -16,7 +16,7 @@
 
 
 /*
-	mode 		- DCL_MODE_COMPR or DCL_MODE_DECMP
+	mode 		- DACT_MODE_COMPR or DACT_MODE_DECMP
 			    Determine whether to compress or decompress.
 	prev_block	- Previous (uncompressed) block.
 	curr_block	- The data to be compressed.
@@ -25,10 +25,10 @@
 */
 int comp_plain_algo(int mode, char *prev_block, char *curr_block, char *out_block, int blk_size) {
 	switch(mode) {
-		case DCL_MODE_COMPR:
+		case DACT_MODE_COMPR:
 			return(comp_plain_compress(prev_block,curr_block,out_block,blk_size));
 			break; /* Heh */
-		case DCL_MODE_DECMP:
+		case DACT_MODE_DECMP:
 			return(comp_plain_decompress(prev_block,curr_block,out_block,blk_size));
 			break;
 		default:
