@@ -1,14 +1,14 @@
-#define DCL_VER_MAJOR 0
-#define DCL_VER_MINOR 3
-#define DCL_VER_REVISION 4
+#define DACT_VER_MAJOR 0
+#define DACT_VER_MINOR 3
+#define DACT_VER_REVISION 10
 
-#ifndef DCL_BLK_SIZE
-#define DCL_BLK_SIZE 1024
+#ifndef DACT_BLK_SIZE
+#define DACT_BLK_SIZE 1024
 #endif
 
 
-#define DCL_MODE_COMPR 1
-#define DCL_MODE_DECMP 2
+#define DACT_MODE_COMPR 1
+#define DACT_MODE_DECMP 2
 
 #ifndef TWO_BYTES
 #if defined(__WIN32__) || defined(GO32)
@@ -20,7 +20,7 @@
 #endif !defined(TWO_BYTES)
 
 
-struct dcl_header {
+struct dact_header {
 	TWO_BYTES	size;
 	unsigned char	algo;
 };
